@@ -58,6 +58,27 @@ coor.graph <- function(X = NULL, only.coor = FALSE, ovlp = TRUE, xl = 1,  res= 8
   if(!requireNamespace("ggplot2",quietly = TRUE))
     stop("'install ggplot2 to use coor.graph()'")
   
+  #### set arguments from options
+  # get function arguments
+  argms <- methods::formalArgs(coor.graph)
+  
+  # get warbleR options
+  opt.argms <- .Options$warbleR
+  
+  # remove options not as default in call and not in function arguments
+  opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
+  
+  # get arguments set in the call
+  call.argms <- as.list(base::match.call())[-1]
+  
+  # remove arguments in options that are in call
+  opt.argms <- opt.argms[!names(opt.argms) %in% names(call.argms)]
+  
+  # set options left
+  if (length(opt.argms) > 0)
+    for (q in 1:length(opt.argms))
+      assign(names(opt.argms)[q], opt.argms[[q]])
+  
   if(!is.data.frame(X))  stop("X is not a data frame")
   
   #stop if some events have less than 10 observations
@@ -198,3 +219,13 @@ if(img){      if(it == "jpeg") ite <- "coor.singing.jpeg" else ite <- "coor.sing
       }
   }))
   }
+
+
+##############################################################################################################
+#' alternative name for \code{\link{coor_graph}}
+#'
+#' @keywords internal
+#' @details see \code{\link{coor_graph}} for documentation. \code{\link{coor.graph}} will be deprecated in future versions.
+#' @export
+
+coor_graph <- coor.graph
