@@ -4,10 +4,10 @@
 #' will be measured by \code{\link{sig2noise}}.
 #' @usage snrspecs(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70, 
 #' inner.mar = c(5, 4, 4, 2), outer.mar = c(0, 0, 0, 0), picsize = 1, 
-#' res = 100, cexlab = 1, title = TRUE, 
-#'   propwidth= FALSE, xl=1, osci = FALSE, gr = FALSE, sc = FALSE, mar = 0.2,
+#' res = 100, cexlab = 1, title = TRUE, before = FALSE, eq.dur = FALSE,
+#'   propwidth= FALSE, xl = 1, osci = FALSE, gr = FALSE, sc = FALSE, mar = 0.2,
 #'    snrmar = 0.1, it = "jpeg", parallel = 1, path = NULL, pb = TRUE)
-#' @param  X 'selection.table' object or data frame with results from \code{\link{manualoc}} or any data frame with columns
+#' @param  X 'selection_table', 'extended_selection_table' or data frame with results from \code{\link{manualoc}} or any data frame with columns
 #' for sound file name (sound.files), selection number (selec), and start and end time of signal
 #' (start and end). 
 #' @param wl A numeric vector of length 1 specifying the window length of the spectrogram, default 
@@ -33,6 +33,9 @@
 #'   labels. See \code{\link[seewave]{spectro}}.
 #' @param title Logical argument to add a title to individual spectrograms. 
 #'   Default is \code{TRUE}.
+#' @param before Logical. If \code{TRUE} noise is only measured right before the signal (instead of before and after). Default is \code{FALSE}.
+#' @param eq.dur Logical. Controls whether the noise segment that is measured has the same duration 
+#' than the signal (if \code{TRUE}, default \code{FALSE}). If \code{TRUE} then 'snrmar' argument is ignored.
 #' @param propwidth Logical argument to scale the width of spectrogram 
 #'   proportionally to duration of the selected call. Default is \code{FALSE}.
 #' @param xl Numeric vector of length 1, a constant by which to scale 
@@ -99,22 +102,49 @@
 #last modification on mar-13-2018 (MAS)
 
 snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70,
-                     inner.mar = c(5,4,4,2), outer.mar = c(0,0,0,0), picsize = 1, res = 100,
-                     cexlab = 1, title = TRUE, propwidth = FALSE, xl = 1, osci = FALSE, 
-                     gr = FALSE, sc = FALSE, mar = 0.2, snrmar = 0.1, it = "jpeg", parallel = 1,
-                     path = NULL, pb = TRUE){
+                     inner.mar = c(5,4,4,2), outer.mar = c(0, 0, 0, 0), picsize = 1, res = 100,
+                     cexlab = 1, title = TRUE, before = FALSE,  eq.dur = FALSE, propwidth = FALSE, 
+                     xl = 1, osci = FALSE, gr = FALSE, sc = FALSE, mar = 0.2, snrmar = 0.1, it = "jpeg",
+                     parallel = 1, path = NULL, pb = TRUE){
  
   # reset working directory 
   wd <- getwd()
   on.exit(setwd(wd))
   
+  # set pb options 
+  on.exit(pbapply::pboptions(type = .Options$pboptions$type), add = TRUE)
+  
+  #### set arguments from options
+  # get function arguments
+  argms <- methods::formalArgs(snrspecs)
+  
+  # get warbleR options
+  opt.argms <- .Options$warbleR
+  
+  # rename path for sound files
+  names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
+  
+  # remove options not as default in call and not in function arguments
+  opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
+  
+  # get arguments set in the call
+  call.argms <- as.list(base::match.call())[-1]
+  
+  # remove arguments in options that are in call
+  opt.argms <- opt.argms[!names(opt.argms) %in% names(call.argms)]
+  
+  # set options left
+  if (length(opt.argms) > 0)
+    for (q in 1:length(opt.argms))
+      assign(names(opt.argms)[q], opt.argms[[q]])
+  
   #check path to working directory
   if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
     setwd(path)
   }  
   
   #if X is not a data frame
-  if(!class(X) %in% c("data.frame", "selection.table")) stop("X is not of a class 'data.frame' or 'selection table")
+  if(!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
   
   if(!all(c("sound.files", "selec", 
             "start", "end") %in% colnames(X))) 
@@ -141,6 +171,8 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70,
   options( show.error.messages = TRUE)
     
   #return warning if not all sound files were found
+  if (!is_extended_selection_table(X))
+  { 
   fs <- list.files(pattern = "\\.wav$", ignore.case = TRUE)
   if(length(unique(X$sound.files[(X$sound.files %in% fs)])) != length(unique(X$sound.files))) 
     cat(paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% fs)])), 
@@ -150,41 +182,28 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70,
   d <- which(X$sound.files %in% fs) 
   if(length(d) == 0){
     stop("The .wav files are not in the working directory")
-  }  else X <- X[d, ]
+  }  else X <- X[d, , drop = FALSE]
+  }
   
   # If parallel is not numeric
   if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
   if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
-    snrspeFUN <- function(i, X, wl, flim, ovlp, inner.mar, outer.mar, picsize, res, cexlab, xl, mar, snrmar){
-    
-    r <- tuneR::readWave(as.character(X$sound.files[i])) 
-    f <- r@samp.rate
+    snrspeFUN <- function(i, X, wl, flim, ovlp, inner.mar, outer.mar, picsize, res, cexlab, xl, mar, snrmar, before, eq.dur){
     
     # Read sound files to get sample rate and length
-    r <- tuneR::readWave(as.character(X$sound.files[i]), header = TRUE)
+    r <- read_wave(X = X, index = i, header = TRUE)
     f <- r$sample.rate
     
     fl<- flim #in case flim its higher than can be due to sampling rate
     if(fl[2] > ceiling(f/2000) - 1) fl[2] <- ceiling(f/2000) - 1 
     
     
+    # set margin if eq.dur
+    if(eq.dur) snrmar <- X$end[i] -  X$start[i]
+    
     # Set mar equals to snrmar if is smaller
     if(mar < snrmar) mar <- snrmar
-    
-    # # Correct start and end time if is smaller than 0 or higher than length of rec
-    # st <- X$start[i] - mar
-    # en <- X$end[i] + mar
-    # mar1 <- mar
-    # 
-    # if (st < 0)  {
-    #   mar1 <- mar1  + st
-    #   st <- 0
-    #   }
-    # 
-    # mar2 <- mar1 + X$end[i] - X$start[i]
-    # 
-    # if(en > r$samples/f) en <- r$samples/f
 
     #reset coordinates of signals 
     st <- X$start[i] - mar
@@ -200,8 +219,7 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70,
     
     if(en > r$samples/f) en <- r$samples/f
     
-    
-    r <- tuneR::readWave(as.character(X$sound.files[i]), from = st, to = en, units = "seconds")
+    r <- read_wave(X = X, index = i, from = st, to = en)
     
     
 # Spectrogram width can be proportional to signal duration
@@ -233,22 +251,16 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70,
       title(paste(X$sound.files[i], "-", X$selec[i], "-", "snr", sep = ""), cex.main = cexlab)
     }
     
-    # Add lines to visualize signal
-    abline(v = c(mar1, mar2), col = "red", lwd = 1.5, lty = "dashed") 
+    # Add boxes to visualize noise region
+    polygon(x = rep(c(mar1 - snrmar, mar1), each = 2), y = c(fl, sort(fl, decreasing = TRUE)), lty = 3, border = "#07889B", lwd = 1.3, col = adjustcolor("#07889B", alpha.f = 0.15))
+
+    text(x = mar1 - (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "#07889B", pos = 3)
     
-    # Add lines to visualize where noise will be measured in sig2noise
-    abline(v = c(mar1 - snrmar, mar2 + snrmar), col = "red", lwd = 1.5, lty = "dashed") 
-    
-    #add arrows/text indicating noise position
-    arrows(x0 =mar1 - snrmar, y0 = fl[1]+fl[2]/6, x1 = mar1, y1 = fl[1]+fl[2]/6, code = 3, 
-           col = "red", lty = "solid", lwd = 2, angle = 60)        
-  
-    arrows(x0 =mar2 + snrmar, y0 = fl[1]+fl[2]/6, x1 = mar2, y1 = fl[1]+fl[2]/6, code = 3, 
-           col = "red", lty = "solid", lwd = 2, angle = 60)        
-    
-    text(x = mar1 - (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3)
-    
-    text(x = mar2 + (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3) 
+    if(!before)
+    {
+      polygon(x = rep(c(mar2, mar2 + snrmar), each = 2), y = c(fl, sort(fl, decreasing = TRUE)), lty = 3, border = "#07889B", lwd = 1.3, col = adjustcolor("#07889B", alpha.f = 0.15)) 
+      text(x = mar2 + (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "#07889B", pos = 3) 
+      }
     
     dev.off()  
     return (NULL)
@@ -264,7 +276,17 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", ovlp = 70,
     # run loop apply function
     out <- pbapply::pblapply(X = 1:nrow(X), cl = cl, FUN = function(i) 
     { 
-      snrspeFUN(X = X, i = i, wl = wl, flim = flim, ovlp = ovlp, inner.mar = inner.mar, outer.mar = outer.mar, picsize = picsize, res = res, cexlab = cexlab, xl = xl, mar = mar, snrmar = snrmar)
+      snrspeFUN(X = X, i = i, wl = wl, flim = flim, ovlp = ovlp, inner.mar = inner.mar, outer.mar = outer.mar, picsize = picsize, res = res, cexlab = cexlab, xl = xl, mar = mar, snrmar = snrmar, before,  eq.dur)
     }) 
 }
 
+
+
+##############################################################################################################
+#' alternative name for \code{\link{snrspecs}}
+#'
+#' @keywords internal
+#' @details see \code{\link{snrspecs}} for documentation. \code{\link{snrspecs}} will be deprecated in future versions.
+#' @export
+
+snr_specs <- snrspecs
