@@ -32,6 +32,30 @@ wavdur <- function(files = NULL, path = NULL) {
   wd <- getwd()
   on.exit(setwd(wd))
   
+  #### set arguments from options
+  # get function arguments
+  argms <- methods::formalArgs(wavdur)
+  
+  # get warbleR options
+  opt.argms <- .Options$warbleR
+  
+  # rename path for sound files
+  names(opt.argms)[names(opt.argms) == "wav.path"] <- "path"
+  
+  # remove options not as default in call and not in function arguments
+  opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
+  
+  # get arguments set in the call
+  call.argms <- as.list(base::match.call())[-1]
+  
+  # remove arguments in options that are in call
+  opt.argms <- opt.argms[!names(opt.argms) %in% names(call.argms)]
+  
+  # set options left
+  if (length(opt.argms) > 0)
+    for (q in 1:length(opt.argms))
+      assign(names(opt.argms)[q], opt.argms[[q]])
+  
   #check path to working directory
   if(is.null(path)) path <- getwd() else {if(!file.exists(path)) stop("'path' provided does not exist") else
     setwd(path)
@@ -52,4 +76,14 @@ wavdur <- function(files = NULL, path = NULL) {
   })
    return(data.frame(sound.files = files, duration = a, row.names = NULL))
 
-  }
+}
+
+
+##############################################################################################################
+#' alternative name for \code{\link{wavdur}}
+#'
+#' @keywords internal
+#' @details see \code{\link{wavdur}} for documentation. \code{\link{wavdur}} will be deprecated in future versions.
+#' @export
+
+wav_dur <- wavdur
