@@ -37,13 +37,33 @@
 
 xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
 
+  #### set arguments from options
+  # get function arguments
+  argms <- methods::formalArgs(xcmaps)
+  
+  # get warbleR options
+  opt.argms <- .Options$warbleR
+  
+  # remove options not as default in call and not in function arguments
+  opt.argms <- opt.argms[!sapply(opt.argms, is.null) & names(opt.argms) %in% argms]
+  
+  # get arguments set in the call
+  call.argms <- as.list(base::match.call())[-1]
+  
+  # remove arguments in options that are in call
+  opt.argms <- opt.argms[!names(opt.argms) %in% names(call.argms)]
+  
+  # set options left
+  if (length(opt.argms) > 0)
+    for (q in 1:length(opt.argms))
+      assign(names(opt.argms)[q], opt.argms[[q]])
+  
   #stop if X is not a data frame
   if(!is.data.frame(X))  stop("X is not a data frame")
 
   #if it argument is not "jpeg" or "tiff" 
-  if(!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))  
-  
-    # Initialize species names (common name)
+  if(!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed")) 
+  # Initialize species names (common name)
   spn <- length(unique(X$English_name))
     
   # Set threshold for maximum number of panels per plot device
@@ -161,3 +181,13 @@ xcmaps <- function(X, img = TRUE, it = "jpeg", res = 100, labels = F) {
     }
   }
 }
+
+
+##############################################################################################################
+#' alternative name for \code{\link{xcmaps}}
+#'
+#' @keywords internal
+#' @details see \code{\link{xcmaps}} for documentation. \code{\link{xcmaps}} will be deprecated in future versions.
+#' @export
+
+xc_maps <- xcmaps
